@@ -5,7 +5,7 @@ import {
     TupleSelector
 } from "@synerty/vortexjs";
 import {AdminStatusTuple, searchFilt} from "@peek/peek_core_search/_private";
-import {Ng2BalloonMsgService} from "@synerty/ng2-balloon-msg";
+import { BalloonMsgService } from "@synerty/peek-plugin-base-js"
 
 
 @Component({
@@ -16,7 +16,7 @@ export class StatusComponent extends ComponentLifecycleEventEmitter {
 
     item: AdminStatusTuple = new AdminStatusTuple();
 
-    constructor(private balloonMsg: Ng2BalloonMsgService,
+    constructor(private balloonMsg: BalloonMsgService,
                 private tupleObserver: TupleDataObserverService) {
         super();
 
@@ -30,4 +30,4 @@ export class StatusComponent extends ComponentLifecycleEventEmitter {
     }
 
 
-}
\ No newline at end of file
+}
