@@ -1,11 +1,14 @@
 from typing import Dict
 
-from peek_core_search._private.PluginNames import searchTuplePrefix
 from vortex.Tuple import addTupleType, TupleField, Tuple
 
+from peek_abstract_chunked_index.private.tuples.ACIUpdateDateTupleABC import \
+    ACIUpdateDateTupleABC
+from peek_core_search._private.PluginNames import searchTuplePrefix
+
 
 @addTupleType
-class SearchObjectUpdateDateTuple(Tuple):
+class SearchObjectUpdateDateTuple(Tuple, ACIUpdateDateTupleABC):
     """ Search Object Update Date Tuple
 
     This tuple represents the state of the chunks in the cache.
@@ -19,3 +22,7 @@ class SearchObjectUpdateDateTuple(Tuple):
 
     initialLoadComplete: bool = TupleField()
     updateDateByChunkKey: Dict[str, str] = TupleField({})
+
+    @property
+    def ckiUpdateDateByChunkKey(self):
+        return self.updateDateByChunkKey
